Struct acid2::simd::SimdF64

source ·
pub struct SimdF64<const LANES: usize>(_)
where
    LaneCount<LANES>: SupportedLaneCount
;
Available on crate feature simd only.

Implementations

The exponent of this 2-adic number.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::Simd;

let f = F64x8::splat(F64::from(8));

assert_eq!(f.exponent(), Simd::splat(3));

The part of this number coprime to 2.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::Simd;

let f = F64x8::splat(F64::from(8));

let f = F64x8::splat(F64::from(36));

assert_eq!(f.significand(), Simd::splat(9));

The exponent and significand of this number, packed together in a tuple.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::Simd;

let f = F64x8::splat(F64::from(12));

assert_eq!(f.exponent_and_significand(), (Simd::splat(2), Simd::splat(3)));

The 2-adic absolute value of this number.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::{Simd, SimdFloat};

let f = F64x8::splat(F64::from(72));

assert_eq!(f.abs(), Simd::splat(2f64.powi(-3)));
assert_eq!(F64x8::splat(F64::ZERO).abs(), Simd::splat(0.0));
assert_eq!(F64x8::splat(F64::INFINITY).abs(), Simd::splat(f64::INFINITY));
assert!(F64x8::splat(F64::NAN).abs().is_nan().all());

Whether or not this number is NaN.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::Simd;

let x = F64x8::splat(F64::ONE);
let y = F64x8::splat(F64::NAN);
let z = F64x8::splat(F64::INFINITY);

assert!(!x.is_nan().any());
assert!(y.is_nan().all());
assert!(!z.is_nan().any());

Whether or not this number is infinite.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::Simd;

let x = F64x8::splat(F64::ONE);
let y = F64x8::splat(F64::NAN);
let z = F64x8::splat(F64::INFINITY);

assert!(!x.is_infinite().any());
assert!(!y.is_infinite().any());
assert!(z.is_infinite().all());

Whether or not this number is finite.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::Simd;

let x = F64x8::splat(F64::ONE);
let y = F64x8::splat(F64::NAN);
let z = F64x8::splat(F64::INFINITY);

assert!(x.is_finite().all());
assert!(!y.is_finite().any());
assert!(!z.is_finite().any());

Computes the 2-adic square root of this number.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::{Simd, SimdPartialOrd};

let f = F64x8::splat(F64::from(81));
let sqrt = f.sqrt();

assert!((sqrt - F64x8::splat(F64::from(9))).abs().simd_le(Simd::splat(1e-15)).all()); // this won't always be true for perfect squares, but in this case it is
assert!((sqrt * sqrt - f).abs().simd_le(Simd::splat(1e-7)).all());

Computes the 2-adic reciprocal of this number.

Examples
#![feature(portable_simd)]
use acid2::{core::F64, simd::F64x8};
use core::simd::{Simd, SimdPartialOrd};

let f = F64x8::splat(F64::from(13));
let recip = f.recip();

assert!((f * recip - F64x8::splat(F64::ONE)).abs().simd_le(Simd::splat(1e-15)).all());